Calculate FACIT-Fatigue subscale score based on number of answered items

calculate_facitf_scale(facitf_sum, facitf_n)

Arguments

facitf_sum

numeric vector with subscale score of FACIT-Fatigue

facitf_n

numeric vector with number of answered items of FACIT-Fatigue

Value

A numeric vector w/ subscale score of FACIT-Fatigue