R/primary-coding-rapid_revive.R
recode_sf36.Rditem coding is wrong in some items of SF-36 questionnaire current levels: 1 = "Yes" and 0 = "No" needed levels: 1 = "Yes" and 2 = "No" function recodes items to needed levels if they were coded incorrectly
recode_sf36(sf36_item.factor)