R/primary-coding-rapid_revive.R
calculate_sf36_points3.Rdeach answer in SF-36 questionnaire corresponds to a specific amount of points, which differ between items this function adds points for items with 2 possible answers
calculate_sf36_points3(sf36)